# 0.1.5 (Thu Oct 07 2021)

#### 🐛 Bug Fix

- Limit joblib version to pre-1.1.0 [#48](https://github.com/con/fscacher/pull/48) ([@jwodder](https://github.com/jwodder))
- Test against and update for dev version of joblib [#42](https://github.com/con/fscacher/pull/42) ([@jwodder](https://github.com/jwodder))

#### 🏠 Internal

- Resimplify release workflow [#35](https://github.com/con/fscacher/pull/35) ([@jwodder](https://github.com/jwodder))
- Remove debug step [#34](https://github.com/con/fscacher/pull/34) ([@jwodder](https://github.com/jwodder))

#### 🧪 Tests

- Test handling of moving symlinks around in git-annex [#47](https://github.com/con/fscacher/pull/47) ([@jwodder](https://github.com/jwodder))

#### Authors: 1

- John T. Wodder II ([@jwodder](https://github.com/jwodder))

---

# 0.1.4 (Mon Feb 22 2021)

#### 🐛 Bug Fix

- Fix versioneer+auto integration (or else) [#33](https://github.com/con/fscacher/pull/33) ([@jwodder](https://github.com/jwodder))

#### Authors: 1

- John T. Wodder II ([@jwodder](https://github.com/jwodder))

---

# 0.1.3 (Mon Feb 22 2021)

#### 🐛 Bug Fix

- Try to debug versioneer failure [#32](https://github.com/con/fscacher/pull/32) ([@jwodder](https://github.com/jwodder))

#### Authors: 1

- John T. Wodder II ([@jwodder](https://github.com/jwodder))

---

# 0.1.2 (Mon Feb 22 2021)

#### 🐛 Bug Fix

- Get auto and versioneer to play nice together [#31](https://github.com/con/fscacher/pull/31) ([@jwodder](https://github.com/jwodder))

#### Authors: 1

- John T. Wodder II ([@jwodder](https://github.com/jwodder))

---

# 0.1.1 (Mon Feb 22 2021)

#### 🐛 Bug Fix

- Get tests to pass on Windows and macOS [#29](https://github.com/con/fscacher/pull/29) ([@jwodder](https://github.com/jwodder))

#### ⚠️ Pushed to `master`

- Start CHANGELOG ([@jwodder](https://github.com/jwodder))

#### 🏠 Internal

- Set up auto [#27](https://github.com/con/fscacher/pull/27) ([@jwodder](https://github.com/jwodder))

#### 🧪 Tests

- Get asv to run pypy3 correctly [#30](https://github.com/con/fscacher/pull/30) ([@jwodder](https://github.com/jwodder))

#### Authors: 1

- John T. Wodder II ([@jwodder](https://github.com/jwodder))

---

# v0.1.0 (2021-02-18)

Initial release
